Installation
============
Ensure that the 'Products.mcdutils' egg is available on your Python path,
e.g.  by running ``easy_install Products.mcdutils`` or including it in your
buildout configuration.
